#!/usr/bin/env python3

import numpy as np
import matplotlib.pyplot as plt


def exact_probs(probs):
  probs = np.array(probs)
  risks = probs / (1 - probs)
  return risks / np.sum(risks)

def estimate_probs(probs, N = 10**6):
  shoots = [np.random.choice([1, 0], size = N, replace = True, p = [p, 1 - p]) for p in probs]
  shoots = np.array(shoots).T

  one_kill = np.sum(shoots, axis = 1) == 1
  one_kill_shoots = shoots[one_kill, :]

  return np.mean(one_kill_shoots, axis = 0)

def sim_killers(probs, N = 10**6):
  shoots = [np.random.choice([1, 0], size = N, replace = True, p = [p, 1 - p]) for p in probs]
  shoots = np.array(shoots).T

  one_kill = np.sum(shoots, axis = 1) == 1
  res = np.zeros(shape = N, dtype = int)
  # res[np.logical_not(one_kill)] = 0
  res[one_kill] = np.argmax(shoots, axis = 1)[one_kill]
  return res

if __name__ == "__main__":
  print(exact_probs([0.1, 0.2, 0.3]))
  print(estimate_probs([0.1, 0.2, 0.3]))

  print(sim_killers([0.1, 0.2, 0.3], N = 10))
