#!/usr/bin/env python3

import numpy as np
from math import pi
import matplotlib.pyplot as plt


def goals_rate(N):
  x, y = [np.random.uniform(low = -1., high = 1., size = N) for _ in range(2)]

  return np.mean(x**2 + y**2 <= 1.)


if __name__ == "__main__":
  exact_prob = pi / 4.
  Ns = [2 ** k for k in range(1, 21)]
  estimates = np.array(list(map(goals_rate, Ns)))
  errors = estimates - exact_prob

  plt.plot(estimates)
  plt.ylabel("Estimate")
  plt.xlabel("Sample size")
  plt.show()

  plt.plot(errors)
  plt.ylabel("Error")
  plt.xlabel("Sample size")
  plt.show()

  plt.plot(Ns, np.abs(errors))
  plt.ylabel("|Error|")
  plt.xlabel("Sample size")
  plt.yscale("log")
  plt.xscale("log")
  plt.show()

  plt.plot(Ns, np.abs(errors) * np.sqrt(Ns))
  plt.ylabel("|Error| * sqrt(N)")
  plt.xlabel("Sample size")
  plt.yscale("log")
  plt.xscale("log")
  plt.show()

  n = 100
  rmses = np.sqrt(np.array([np.mean((np.array([goals_rate(N) for _ in range(n)]) - exact_prob) ** 2) for N in Ns]))

  plt.plot(Ns, rmses)
  plt.ylabel("|RMSE|")
  plt.xlabel("Sample size")
  plt.yscale("log")
  plt.xscale("log")
  plt.show()


